-- - prologDb2.ddl start ---------------------------------------------
-- Version: 1.2
-- -------------------------------------------------------------------
-- DDL for @PRODUCT.SERVER@ @PRODUCT.VERSION.DETAIL@ - @BLDLEVEL@
--
-- Create the IBM DB2 version of the Database tables.
--
-- DB2 8.1 Documentation:
-- http://www-306.ibm.com/software/data/db2/library/
-- - prologDb2.ddl end -----------------------------------------------


-- Generated by Relational Schema Center on Thu May 03 11:52:46 CDT 2007 for DB2 Universal Database V8.2

-- The DROP statements are removed intentionally to enable migration of existing policies
-- ALTER TABLE OPERATIONS DROP FOREIGN KEY FK_SERVICE;

-- ALTER TABLE POLICIES DROP FOREIGN KEY FK_REQUESTER;

-- ALTER TABLE POLICIES DROP FOREIGN KEY FK_SVCOPERATION;

-- ALTER TABLE POLICIES DROP FOREIGN KEY FK_POLICYTYPE;

-- DROP TABLE REQUESTERS;

-- DROP TABLE SERVICES;

-- DROP TABLE OPERATIONS;

-- DROP TABLE POLICYTYPES;

-- DROP TABLE POLICIES;

CREATE TABLE REQUESTERS
  (REQUESTER VARCHAR(250) NOT NULL,
   ENABLED SMALLINT NOT NULL DEFAULT 1,
   TYPE SMALLINT NOT NULL,
   DESCRIPTION VARCHAR(250),
   PARENT VARCHAR(250),
   LINDEX INTEGER NOT NULL,
   RINDEX INTEGER NOT NULL);

ALTER TABLE REQUESTERS
  ADD CONSTRAINT PK_REQUESTERS PRIMARY KEY (REQUESTER);

COMMENT ON COLUMN REQUESTERS.REQUESTER IS 'Requester name';

COMMENT ON COLUMN REQUESTERS.ENABLED IS 'Requester status';

COMMENT ON COLUMN REQUESTERS.TYPE IS 'Type of the requester';

COMMENT ON COLUMN REQUESTERS.DESCRIPTION IS 'Requester description';

COMMENT ON COLUMN REQUESTERS.PARENT IS 'Requester parent';

COMMENT ON COLUMN REQUESTERS.LINDEX IS 'Automatically generated pre-order tree traversal number';

COMMENT ON COLUMN REQUESTERS.RINDEX IS 'Automatically generated pre-order tree traversal number';

CREATE TABLE SERVICES
  (SERVICE VARCHAR(250) NOT NULL,
   ENABLED SMALLINT NOT NULL DEFAULT 1,
   TYPE SMALLINT NOT NULL,
   DESCRIPTION VARCHAR(250),
   PARENT VARCHAR(250),
   LINDEX INTEGER NOT NULL,
   RINDEX INTEGER NOT NULL);

ALTER TABLE SERVICES
  ADD CONSTRAINT PK_SERVICES PRIMARY KEY (SERVICE);

COMMENT ON COLUMN SERVICES.SERVICE IS 'Service Name';

COMMENT ON COLUMN SERVICES.ENABLED IS 'Service status';

COMMENT ON COLUMN SERVICES.TYPE IS 'Service type';

COMMENT ON COLUMN SERVICES.DESCRIPTION IS 'Service description';

COMMENT ON COLUMN SERVICES.PARENT IS 'Service group';

COMMENT ON COLUMN SERVICES.LINDEX IS 'Automatically generated pre-order tree traversal number';

COMMENT ON COLUMN SERVICES.RINDEX IS 'Automatically generated pre-order tree traversal number';

CREATE TABLE OPERATIONS
  (SERVICE VARCHAR(250) NOT NULL,
   OPERATION VARCHAR(250) NOT NULL,
   ENABLED SMALLINT NOT NULL DEFAULT 1,
   DESCRIPTION VARCHAR(250));

ALTER TABLE OPERATIONS
  ADD CONSTRAINT PK_OPERATIONS PRIMARY KEY (SERVICE, OPERATION);

COMMENT ON COLUMN OPERATIONS.SERVICE IS 'Service name';

COMMENT ON COLUMN OPERATIONS.OPERATION IS 'Operation name';

COMMENT ON COLUMN OPERATIONS.ENABLED IS 'Operation status';

COMMENT ON COLUMN OPERATIONS.DESCRIPTION IS 'Operation description';

CREATE TABLE POLICYTYPES
  (POLICYTYPE VARCHAR(250) NOT NULL,
   EDITABLE SMALLINT NOT NULL DEFAULT 1,
   EDITMASK VARCHAR(250) NOT NULL,
   DESCRIPTION VARCHAR(250),
   ENCRYPTED SMALLINT NOT NULL DEFAULT 0);

ALTER TABLE POLICYTYPES
  ADD CONSTRAINT PK_POLICYTYPES PRIMARY KEY (POLICYTYPE);

COMMENT ON COLUMN POLICYTYPES.POLICYTYPE IS 'Policy type name';

COMMENT ON COLUMN POLICYTYPES.EDITABLE IS 'If policy values of the type is editable';

COMMENT ON COLUMN POLICYTYPES.EDITMASK IS 'Edit constratints for the policy type (Java 1.4 regexp)';

COMMENT ON COLUMN POLICYTYPES.DESCRIPTION IS 'Policy type description';

CREATE TABLE POLICIES
  (REQUESTER VARCHAR(250) NOT NULL,
   SERVICE VARCHAR(250) NOT NULL,
   OPERATION VARCHAR(250) NOT NULL,
   POLICYNAME VARCHAR(250) NOT NULL,
   POLICYTYPE VARCHAR(250) NOT NULL,
   POLICYVALUE VARCHAR(250) NOT NULL);

ALTER TABLE POLICIES
  ADD CONSTRAINT PK_POLICIES PRIMARY KEY (REQUESTER, SERVICE, OPERATION, POLICYNAME);

COMMENT ON COLUMN POLICIES.REQUESTER IS 'Requester name';

COMMENT ON COLUMN POLICIES.SERVICE IS 'Service Name';

COMMENT ON COLUMN POLICIES.OPERATION IS 'Operation name';

COMMENT ON COLUMN POLICIES.POLICYNAME IS 'Policy name';

COMMENT ON COLUMN POLICIES.POLICYTYPE IS 'Policy type';

COMMENT ON COLUMN POLICIES.POLICYVALUE IS 'Policy value';

ALTER TABLE OPERATIONS
  ADD CONSTRAINT FK_SERVICE FOREIGN KEY (SERVICE)
  REFERENCES SERVICES(SERVICE)
  ON DELETE CASCADE
  ON UPDATE RESTRICT;

ALTER TABLE POLICIES
  ADD CONSTRAINT FK_REQUESTER FOREIGN KEY (REQUESTER)
  REFERENCES REQUESTERS(REQUESTER)
  ON DELETE CASCADE
  ON UPDATE RESTRICT;

ALTER TABLE POLICIES
  ADD CONSTRAINT FK_SVCOPERATION FOREIGN KEY (SERVICE, OPERATION)
  REFERENCES OPERATIONS(SERVICE, OPERATION)
  ON DELETE CASCADE
  ON UPDATE RESTRICT;

ALTER TABLE POLICIES
  ADD CONSTRAINT FK_POLICYTYPE FOREIGN KEY (POLICYTYPE)
  REFERENCES POLICYTYPES(POLICYTYPE)
  ON DELETE CASCADE
  ON UPDATE RESTRICT;
--   -- -------------------------------

-- -----  Insert predefined requesters to Requesters table
INSERT INTO REQUESTERS VALUES ('ALL', 1, 0, 'Policy Manager ALL requester group---CAN NOT BE REMOVED', '', 1, 8);
INSERT INTO REQUESTERS VALUES ('unauthenticated', 0, 1, 'Unauthenticated requester', 'ALL', 2,3);
INSERT INTO REQUESTERS VALUES ('authenticated', 1, 0, 'Authenticated requester group', 'ALL', 4, 7);
INSERT INTO REQUESTERS VALUES ('anonymous.invalid', 1, 1, 'Anonymous requester', 'authenticated', 5, 6);

-- -----  Insert predefined service to Services table
INSERT INTO SERVICES VALUES ('ALL', 1, 0, 'Policy Manager ALL service group---CAN NOT BE REMOVED', '', 1, 2);


--   -- Insert 'ALL' operation to ALL service in Operations table
--   -- -------------------------------
INSERT INTO OPERATIONS  VALUES (  'ALL', 'ALL', 1, 'All Service Operation for ALL service---CAN NOT BE REMOVED');


--   ----  Insert pre-defined policy data types to PolicyTypes table
---------                            POLICYTYPE             , EDITABLE,EDITMASK                      ,  DESCRIPTION                                      ENCRYPTED                                           
INSERT INTO POLICYTYPES VALUES ( 'ReadOnlyString'           ,     0   ,  '.+'                        , 'Any string value not empty, read only.'           , 0   );
INSERT INTO POLICYTYPES VALUES ( 'RequiredString'           ,     1   ,  '.+'                        , 'Any string value not empty, read only.'           , 0   );
INSERT INTO POLICYTYPES VALUES ( 'String'                   ,     1   ,  '.*'                        , 'Any string value, may be empty'                   , 0   );
INSERT INTO POLICYTYPES VALUES ('Numeric'                   ,     1   ,  '[0-9]*'                    , 'Any positive numeric value.'                      , 0   );
INSERT INTO POLICYTYPES VALUES ('RequiredNumeric'           ,     1   ,  '[0-9]+'                    , 'Any positive numeric value.'                      , 0   );
INSERT INTO POLICYTYPES VALUES ( 'Boolean'                  ,     1   ,  '(true)|(false)'            , 'boolean true or false.'                           , 0   );
INSERT INTO POLICYTYPES VALUES ( 'URI'                      ,     1   ,  '^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?' , 'A URL, for example http://www.ibm.com.',  0);
INSERT INTO POLICYTYPES VALUES ( 'TimeSpecification'        ,     1   ,  '(Millisecond)|(Second)|(Minute)|(Hour)|(Day)|(Week)|(Month)|(Year)' , 'Valid values for Parlay X TimeMetric data structure.', 0 );
INSERT INTO POLICYTYPES VALUES ( 'ReportingInterval'        ,     1   ,  '(Millisecond)|(Second)'    , 'Reporting interval precision for Parlay notificaiton calls.' , 0 );
INSERT INTO POLICYTYPES VALUES ( 'IntegerList'              ,     1   ,  '[0-9]+(,[0-9]+)*'          , 'Any positive numeric comma seperated list (not empty).'      , 0 );
INSERT INTO POLICYTYPES VALUES ( 'StringList'               ,     1   ,  '[^,]+(,[^,]+)*'            , 'Any comma seperated list (not empty).'                       , 0 );
INSERT INTO POLICYTYPES VALUES ( 'Password'                 ,     1   ,  '.+'            , 'Encrypted password (no empty).'                                , 1  );


COMMIT;

QUIT;
