-- - prologOra.ddl start ---------------------------------------------
-- Version: 1.2
-- -------------------------------------------------------------------
-- DDL for @PRODUCT.SERVER@ @PRODUCT.VERSION.DETAIL@ - @BLDLEVEL@
--
-- Create the Oracle version of the Database tables.
--
-- Oracle 9i2 Documentation (free registration required):
-- http://technet.oracle.com
-- -------------------------------------------------------------------
set linesize 2048
set pagesize 1024
set echo on
-- - prologOra.ddl end -----------------------------------------------


-- Generated by Relational Schema Center on Thu May 03 11:54:17 CDT 2007 for Oracle10g

-- The DROP statements are removed intentionally to enable migration of existing policies
-- ALTER TABLE OPERATIONS DROP CONSTRAINT FK_SERVICE;

-- ALTER TABLE POLICIES DROP CONSTRAINT FK_REQUESTER;

-- ALTER TABLE POLICIES DROP CONSTRAINT FK_SVCOPERATION;

-- ALTER TABLE POLICIES DROP CONSTRAINT FK_POLICYTYPE;
   

-- DROP TABLE REQUESTERS CASCADE CONSTRAINTS;

-- DROP TABLE SERVICES CASCADE CONSTRAINTS;

-- DROP TABLE OPERATIONS CASCADE CONSTRAINTS;

-- DROP TABLE POLICYTYPES CASCADE CONSTRAINTS;

-- DROP TABLE POLICIES CASCADE CONSTRAINTS;
   

CREATE TABLE REQUESTERS
  (REQUESTER VARCHAR2(250 CHAR) NOT NULL,
   ENABLED SMALLINT DEFAULT 1 NOT NULL,
   TYPE SMALLINT NOT NULL,
   DESCRIPTION VARCHAR2(250 CHAR) NULL,
   PARENT VARCHAR2(250 CHAR) NULL,
   LINDEX INTEGER NOT NULL,
   RINDEX INTEGER NOT NULL);

ALTER TABLE REQUESTERS
  ADD CONSTRAINT PK_REQUESTERS PRIMARY KEY (REQUESTER);

COMMENT ON COLUMN REQUESTERS.REQUESTER IS 'Requester name';

COMMENT ON COLUMN REQUESTERS.PARENT IS 'Requester group name';

COMMENT ON COLUMN REQUESTERS.LINDEX IS 'Automatically generated pre-order tree traversal number';

COMMENT ON COLUMN REQUESTERS.RINDEX IS 'Automatically generated pre-order tree traversal number';

CREATE TABLE SERVICES
  (SERVICE VARCHAR2(250 CHAR) NOT NULL,
   ENABLED SMALLINT DEFAULT 1 NOT NULL,
   TYPE VARCHAR2(250 CHAR) NOT NULL,
   DESCRIPTION VARCHAR2(250 CHAR) NULL,
   PARENT VARCHAR2(250 CHAR) NULL,
   LINDEX INTEGER NOT NULL,
   RINDEX INTEGER NOT NULL);

ALTER TABLE SERVICES
  ADD CONSTRAINT PK_SERVICES PRIMARY KEY (SERVICE);

COMMENT ON COLUMN SERVICES.SERVICE IS 'Service name';

COMMENT ON COLUMN SERVICES.TYPE IS 'Service type';

COMMENT ON COLUMN SERVICES.DESCRIPTION IS 'Service description';

COMMENT ON COLUMN SERVICES.PARENT IS 'Service group name';

COMMENT ON COLUMN SERVICES.LINDEX IS 'Automatically generated pre-order tree traversal number';

COMMENT ON COLUMN SERVICES.RINDEX IS 'Automatically generated pre-order tree traversal number';

CREATE TABLE OPERATIONS
  (SERVICE VARCHAR2(250 CHAR) NOT NULL,
   OPERATION VARCHAR2(250 CHAR) NOT NULL,
   ENABLED SMALLINT DEFAULT 1 NOT NULL,
   DESCRIPTION VARCHAR2(250 CHAR) NULL);

ALTER TABLE OPERATIONS
  ADD CONSTRAINT PK_OPERATIONS PRIMARY KEY (SERVICE, OPERATION);

COMMENT ON COLUMN OPERATIONS.SERVICE IS 'Service name';

COMMENT ON COLUMN OPERATIONS.OPERATION IS 'Operation name';

CREATE TABLE POLICYTYPES
  (POLICYTYPE VARCHAR2(250 CHAR) NOT NULL,
   EDITABLE SMALLINT DEFAULT 1 NOT NULL,
   EDITMASK VARCHAR2(250 CHAR) NOT NULL,
   DESCRIPTION VARCHAR2(250 CHAR) NULL,
   ENCRYPTED SMALLINT DEFAULT 0 NOT NULL);

ALTER TABLE POLICYTYPES
  ADD CONSTRAINT PK_POLICYTYPES PRIMARY KEY (POLICYTYPE);

COMMENT ON COLUMN POLICYTYPES.POLICYTYPE IS 'Policy type';

COMMENT ON COLUMN POLICYTYPES.EDITABLE IS 'If policy values of the type is editable';

COMMENT ON COLUMN POLICYTYPES.EDITMASK IS 'Edit constratints (Java 1.4 regexp)';

COMMENT ON COLUMN POLICYTYPES.DESCRIPTION IS 'Policy type description';

CREATE TABLE POLICIES
  (REQUESTER VARCHAR2(250 CHAR) NOT NULL,
   SERVICE VARCHAR2(250 CHAR) NOT NULL,
   OPERATION VARCHAR2(250 CHAR) NOT NULL,
   POLICYNAME VARCHAR2(250 CHAR) NOT NULL,
   POLICYTYPE VARCHAR2(250 CHAR) NOT NULL,
   POLICYVALUE VARCHAR2(250 CHAR) NOT NULL);

ALTER TABLE POLICIES
  ADD CONSTRAINT PK_POLICIES PRIMARY KEY (REQUESTER, SERVICE, OPERATION, POLICYNAME);

COMMENT ON COLUMN POLICIES.REQUESTER IS 'Requester name';

COMMENT ON COLUMN POLICIES.SERVICE IS 'Service name';

COMMENT ON COLUMN POLICIES.OPERATION IS 'Operation name';

COMMENT ON COLUMN POLICIES.POLICYNAME IS 'Policy name';

COMMENT ON COLUMN POLICIES.POLICYTYPE IS 'Policy type';

COMMENT ON COLUMN POLICIES.POLICYVALUE IS 'Policy value';

ALTER TABLE OPERATIONS
  ADD CONSTRAINT FK_SERVICE FOREIGN KEY (SERVICE)
  REFERENCES SERVICES(SERVICE)
  ON DELETE CASCADE;

ALTER TABLE POLICIES
  ADD CONSTRAINT FK_REQUESTER FOREIGN KEY (REQUESTER)
  REFERENCES REQUESTERS(REQUESTER)
  ON DELETE CASCADE;

ALTER TABLE POLICIES
  ADD CONSTRAINT FK_SVCOPERATION FOREIGN KEY (SERVICE, OPERATION)
  REFERENCES OPERATIONS(SERVICE, OPERATION)
  ON DELETE CASCADE;

ALTER TABLE POLICIES
  ADD CONSTRAINT FK_POLICYTYPE FOREIGN KEY (POLICYTYPE)
  REFERENCES POLICYTYPES(POLICYTYPE)
  ON DELETE CASCADE;
--   -- -------------------------------

-- -----  Insert predefined requesters to Requesters table
INSERT INTO REQUESTERS VALUES ('ALL', 1, 0, 'Policy Manager ALL requester group---CAN NOT BE REMOVED', '', 1, 8);
INSERT INTO REQUESTERS VALUES ('unauthenticated', 0, 1, 'Unauthenticated requester', 'ALL', 2,3);
INSERT INTO REQUESTERS VALUES ('authenticated', 1, 0, 'Authenticated requester group', 'ALL', 4, 7);
INSERT INTO REQUESTERS VALUES ('anonymous.invalid', 1, 1, 'Anonymous requester', 'authenticated', 5, 6);

-- -----  Insert predefined service to Services table
INSERT INTO SERVICES VALUES ('ALL', 1, 0, 'Policy Manager ALL service group---CAN NOT BE REMOVED', '', 1, 2);


--   -- Insert 'ALL' operation to ALL service in Operations table
--   -- -------------------------------
INSERT INTO OPERATIONS  VALUES (  'ALL', 'ALL', 1, 'All Service Operation for ALL service---CAN NOT BE REMOVED');


--   ----  Insert pre-defined policy data types to PolicyTypes table
---------                            POLICYTYPE             , EDITABLE,EDITMASK                      ,  DESCRIPTION                                      ENCRYPTED                                           
INSERT INTO POLICYTYPES VALUES ( 'ReadOnlyString'           ,     0   ,  '.+'                        , 'Any string value not empty, read only.'           , 0   );
INSERT INTO POLICYTYPES VALUES ( 'RequiredString'           ,     1   ,  '.+'                        , 'Any string value not empty, read only.'           , 0   );
INSERT INTO POLICYTYPES VALUES ( 'String'                   ,     1   ,  '.*'                        , 'Any string value, may be empty'                   , 0   );
INSERT INTO POLICYTYPES VALUES ('Numeric'                   ,     1   ,  '[0-9]*'                    , 'Any positive numeric value.'                      , 0   );
INSERT INTO POLICYTYPES VALUES ('RequiredNumeric'           ,     1   ,  '[0-9]+'                    , 'Any positive numeric value.'                      , 0   );
INSERT INTO POLICYTYPES VALUES ( 'Boolean'                  ,     1   ,  '(true)|(false)'            , 'boolean true or false.'                           , 0   );
INSERT INTO POLICYTYPES VALUES ( 'URI'                      ,     1   ,  '^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?' , 'A URL, for example http://www.ibm.com.',  0);
INSERT INTO POLICYTYPES VALUES ( 'TimeSpecification'        ,     1   ,  '(Millisecond)|(Second)|(Minute)|(Hour)|(Day)|(Week)|(Month)|(Year)' , 'Valid values for Parlay X TimeMetric data structure.', 0 );
INSERT INTO POLICYTYPES VALUES ( 'ReportingInterval'        ,     1   ,  '(Millisecond)|(Second)'    , 'Reporting interval precision for Parlay notificaiton calls.' , 0 );
INSERT INTO POLICYTYPES VALUES ( 'IntegerList'              ,     1   ,  '[0-9]+(,[0-9]+)*'          , 'Any positive numeric comma seperated list (not empty).'      , 0 );
INSERT INTO POLICYTYPES VALUES ( 'StringList'               ,     1   ,  '[^,]+(,[^,]+)*'            , 'Any comma seperated list (not empty).'                       , 0 );
INSERT INTO POLICYTYPES VALUES ( 'Password'                 ,     1   ,  '.+'            , 'Encrypted password (no empty).'                                , 1  );


COMMIT;

QUIT;
